@@ -177,7 +177,6 @@ class OctaveEngine(object):
         cmds = []
         if settings['backend'] == 'inline':
             cmds.append("set(0, 'defaultfigurevisible', 'off');")
-            cmds.append("graphics_toolki('gnuplot')")
         else:
             cmds.append("set(0, 'defaultfigurevisible', 'on');")
             cmds.append("graphics_toolkit('%s');" % settings['backend'])
@@ -280,6 +279,7 @@ class OctaveEngine(object):
 
     def _startup(self, plot_settings):
         cwd = os.getcwd().replace(os.path.sep, '/')
+        self.eval("graphics_toolkit('gnuplot')", silent=True)
         self.eval('more off; source ~/.octaverc; cd("%s");' % cwd, silent=True)
         here = os.path.realpath(os.path.dirname(__file__))
         self.eval('addpath("%s")' % here.replace(os.path.sep, '/'))
@@ -338,7 +338,11 @@ class OctaveEngine(object):
                 cmd += ' --no-gui'
         # Interactive mode prevents crashing on Windows on syntax errors.
         # Delay sourcing the "~/.octaverc" file in case it displays a pager.
-        cmd += ' --interactive --quiet --no-init-file'
+        cmd += ' --interactive --quiet --no-init-file '
+
+        # Add cli options provided by the user.
+        cmd += os.environ.get('OCTAVE_CLI_OPTIONS', '')
+
         orig_prompt = u('octave.*>')
         change_prompt = u("PS1('{0}'); PS2('{1}')")
 
